View source: R/ctrFindActiveSubstanceSynonyms.R
| ctrFindActiveSubstanceSynonyms | R Documentation |
An active substance can be identified by a recommended international nonproprietary name (INN), a trade or product name, or a company code(s). To find likely synonyms, the function retrieves from CTGOV2 the field protocolSection.armsInterventionsModule.interventions. Note this is mostly manually filled, thus may not be free of errors.
ctrFindActiveSubstanceSynonyms(activesubstance = "", verbose = FALSE)
activesubstance |
An active substance, in an atomic character vector |
verbose |
Print number of studies found in CTGOV2 for 'activesubstance' |
A named character vector of the active substance (input parameter), the MeSH term(s) and various names (other than the MeSH term) used in registered studies, or NULL if the active substance was not found and may be invalid. The active substances are ordered in decreasing number of occurrence.
## Not run:
ctrFindActiveSubstanceSynonyms(activesubstance = "imatinib")
# activesubstance mesh
# "imatinib" "imatinib mesylate" "imatinib" "gleevec" "glivec"
# "STI571" "CGP57148" "CGP57148B" "NSC716051"
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.